netapp_ontap.models.qtree_user API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.qtree_user`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class QtreeUserSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the QtreeUser object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `id POST PATCH`

    The numeric ID of the user who owns the qtree. Valid in POST or PATCH.

    Example: 10001

  `name POST PATCH`

    Alphanumeric username of user who owns the qtree. Valid in POST or PATCH.

    Example: unix_user1